@@ -23,9 +23,11 @@ It uses the generic `gc3libs.cmdline.SessionBasedScript` framework.
 
 See the output of ``gcodeml --help`` for program usage instructions.
 """
-__version__ = '2.0.3 version (SVN $Revision$)'
+__version__ = '2.0.4 version (SVN $Revision$)'
 # summary of user-visible changes
 __changelog__ = """
+  2013-02-18:
+    * Output files places in same folder as inputs.
   2012-12-05:
     * Allow requesting a specific version of CODEML/PAML
       via a command-line option.
@@ -204,10 +206,6 @@ of newly-created jobs so that this limit is never exceeded.
                     "The input directory '%s' must contain exactly two control files." % dirpath)
 
             self.log.debug("Gathered control files: '%s':" % str.join("', '", ctl_files))
-            # set optional arguments (path to 'codeml' binary, output URL, etc.)
-            kwargs = extra.copy()
-            if self.params.output_base_url != "":
-               kwargs['output_base_url'] = self.params.output_base_url
 
             ## create new CODEML application instance
 
@@ -224,7 +222,20 @@ of newly-created jobs so that this limit is never exceeded.
             # `SessionBasedScript`) to expand strings like
             # ``NAME``, etc. in the template.
             jobname = (os.path.basename(dirpath) or dirpath) + '.out'
-            kwargs['output_dir'] = self.make_directory_path(self.params.output, jobname)
+
+
+            # kwargs['output_dir'] = self.make_directory_path(self.params.output, jobname)
+
+            # Variant 1: results in same folder as inputs
+            kwargs['output_dir'] = os.path.join(dirpath,'.compute')
+            kwargs['result_dir'] = dirpath
+
+            # FIXME: should this reflect the same policy as 'output_dir' ?
+            # set optional arguments (path to 'codeml' binary, output URL, etc.)
+            kwargs = extra.copy()
+            if self.params.output_base_url != "":
+               kwargs['output_base_url'] = self.params.output_base_url
+
 
             app = CodemlApplication(*ctl_files, **kwargs)
 
